@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amd.c,v 1.2 1998/12/27 06:24:45 ezk Exp $
+ * $Id: amd.c,v 1.8.2.3 2001/01/10 03:22:59 ezk Exp $
  *
  */
 
@@ -55,13 +55,7 @@
 struct amu_global_options gopt;	/* where global options are stored */
 
 char pid_fsname[16 + MAXHOSTNAMELEN];	/* "kiska.southseas.nz:(pid%d)" */
-#if 0
-char *progname;			/* "amd" */
-#endif
 char *hostdomain = "unknown.domain";
-#if 0
-char hostname[MAXHOSTNAMELEN + 1] = "localhost"; /* Hostname */
-#endif
 char hostd[2 * MAXHOSTNAMELEN + 1]; /* Host+domain */
 char *endian = ARCH_ENDIAN;	/* Big or Little endian */
 char *cpu = HOST_CPU;		/* CPU type */
@@ -73,11 +67,6 @@ int orig_umask = 022;
 int select_intr_valid;
 
 jmp_buf select_intr;
-#if 0
-pid_t mypid;			/* Current process id */
-serv_state amd_state;
-int foreground = 1;		/* This is the top-level server */
-#endif
 struct amd_stats amd_stats;	/* Server statistics */
 struct in_addr myipaddr;	/* (An) IP address of this host */
 time_t do_mapc_reload = 0;	/* mapc_reload() call required? */
@@ -188,8 +177,8 @@ daemon_mode(void)
   if (gopt.flags & CFM_PRINT_PID) {
     if (STREQ(gopt.pid_file, "/dev/stdout")) {
       printf("%ld\n", (long) am_mypid);
+      /* flush stdout, just in case */
       fflush(stdout);
-      /* do not fclose stdout */
     } else {
       FILE *f;
       mode_t prev_umask = umask(0022); /* set secure temporary umask */
@@ -259,6 +248,12 @@ init_global_options(void)
   /* OS version */
   gopt.op_sys_ver = HOST_OS_VERSION;
 
+  /* full OS name and version */
+  gopt.op_sys_full = HOST_OS;
+
+  /* OS version */
+  gopt.op_sys_vendor = HOST_VENDOR;
+
   /* pid file */
   gopt.pid_file = "/dev/stdout";
 
@@ -481,7 +476,7 @@ main(int argc, char *argv[])
   verstr = strtok(get_version_string(), "\n");
   plog(XLOG_INFO, "AM-UTILS VERSION INFORMATION:");
   while (verstr) {
-    plog(XLOG_INFO, verstr);
+    plog(XLOG_INFO, "%s", verstr);
     verstr = strtok(NULL, "\n");
   }
 
@@ -490,7 +485,7 @@ main(int argc, char *argv[])
    * can mount the automounter.
    */
   amu_get_myaddress(&myipaddr);
-  plog(XLOG_INFO, "My ip addr is 0x%x", htonl(myipaddr.s_addr));
+  plog(XLOG_INFO, "My ip addr is %s", inet_ntoa(myipaddr));
 
   /* avoid hanging on other NFS servers if started elsewhere */
   if (chdir("/") < 0)
@@ -500,7 +495,7 @@ main(int argc, char *argv[])
    * Now check we are root.
    */
   if (geteuid() != 0) {
-    plog(XLOG_FATAL, "Must be root to mount filesystems (euid = %d)", geteuid());
+    plog(XLOG_FATAL, "Must be root to mount filesystems (euid = %ld)", (long) geteuid());
     going_down(1);
   }
 
@@ -509,6 +504,16 @@ main(int argc, char *argv[])
    */
 #ifdef HAVE_PLOCK
   if (gopt.flags & CFM_PROCESS_LOCK) {
+# ifdef _AIX
+    /*
+     * On AIX you must lower the stack size using ulimit() before calling
+     * plock.  Otherwise plock will reserve a lot of memory space based on
+     * your maximum stack size limit.  Since it is not easily possible to
+     * tell what should the limit be, I print a warning before calling
+     * plock().  See the manual pages for ulimit(1,3,4) on your AIX system.
+     */
+    plog(XLOG_WARNING, "AIX: may need to lower stack size using ulimit(3) before calling plock");
+# endif /* _AIX */
     if (plock(PROCLOCK) != 0) {
       plog(XLOG_WARNING, "Couldn't lock process text and data segment in memory: %m");
     } else {
