@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amfs_host.c,v 1.4.2.2 2001/01/12 23:28:56 ro Exp $
+ * $Id: amfs_host.c,v 1.4.2.4 2001/05/19 02:00:58 ib42 Exp $
  *
  */
 
@@ -402,7 +402,6 @@ amfs_host_fmount(mntfs *mf)
    * Figure out how many exports were returned
    */
   for (n_export = 0, ex = exlist; ex; ex = ex->ex_next) {
-    /* printf("export %s\n", ex->ex_dir); */
     n_export++;
   }
 
@@ -414,7 +413,10 @@ amfs_host_fmount(mntfs *mf)
   ep = (exports *) xmalloc(n_export * sizeof(exports));
   for (j = 0, ex = exlist; ex; ex = ex->ex_next) {
     make_mntpt(mntpt, ex, mf);
-    if (!already_mounted(mlist, mntpt))
+    if (already_mounted(mlist, mntpt))
+      /* we have at least one mounted f/s, so don't fail the mount */
+      ok = TRUE;
+    else
       ep[j++] = ex;
   }
   n_export = j;
