@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amfs_toplvl.c,v 1.7.2.1 2001/01/10 03:23:03 ezk Exp $
+ * $Id: amfs_toplvl.c,v 1.7.2.2 2001/04/14 21:08:20 ezk Exp $
  *
  */
 
@@ -309,7 +309,7 @@ amfs_toplvl_mount(am_node *mp)
   error = mount_amfs_toplvl(mf->mf_mount, opts);
   if (error) {
     errno = error;
-    plog(XLOG_FATAL, "mount_amfs_toplvl: %m");
+    plog(XLOG_FATAL, "amfs_toplvl_mount: mount_amfs_toplvl failed: %m");
     return error;
   }
   return 0;
