@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amq_svc.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
+ * $Id: amq_svc.c,v 1.4.2.2 2001/01/12 22:43:42 ro Exp $
  *
  */
 
@@ -59,7 +59,6 @@ amq_program_1(struct svc_req *rqstp, SVCXPRT *transp)
     amq_string amqproc_mnttree_1_arg;
     amq_string amqproc_umnt_1_arg;
     amq_setopt amqproc_setopt_1_arg;
-    amq_string amqproc_mount_1_arg;
   } argument;
   char *result;
   xdrproc_t xdr_argument, xdr_result;
@@ -109,12 +108,6 @@ amq_program_1(struct svc_req *rqstp, SVCXPRT *transp)
     local = (amqsvcproc_t) amqproc_getmntfs_1_svc;
     break;
 
-  case AMQPROC_MOUNT:
-    xdr_argument = (xdrproc_t) xdr_amq_string;
-    xdr_result = (xdrproc_t) xdr_int;
-    local = (amqsvcproc_t) amqproc_mount_1_svc;
-    break;
-
   case AMQPROC_GETVERS:
     xdr_argument = (xdrproc_t) xdr_void;
     xdr_result = (xdrproc_t) xdr_amq_string;
