@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: clock.c,v 1.1.1.1 1998/11/05 02:04:47 ezk Exp $
+ * $Id: clock.c,v 1.4.2.1 2001/01/10 03:23:04 ezk Exp $
  *
  */
 
@@ -190,7 +190,8 @@ reschedule_timeouts(time_t now, time_t then)
     if (cp->c_time >= now && cp->c_time <= then) {
       plog(XLOG_WARNING, "job %d rescheduled to run immediately", cp->c_id);
 #ifdef DEBUG
-      dlog("rescheduling job %d back %d seconds", cp->c_id, cp->c_time - now);
+      dlog("rescheduling job %d back %ld seconds",
+	   cp->c_id, (long) (cp->c_time - now));
 #endif /* DEBUG */
       next_softclock = cp->c_time = now;
     }
