@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: info_ldap.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
+ * $Id: info_ldap.c,v 1.9.2.2 2001/01/12 23:28:56 ro Exp $
  *
  */
 
@@ -127,24 +127,25 @@ he_free(HE *h)
 
 
 static HE *
-string2he(char *s)
+string2he(char *s_orig)
 {
   char *c, *p;
+  char *s;
   HE *new, *old = NULL;
 
-  if (s == NULL)
-    return (NULL);
+  if (NULL == s_orig || NULL == (s = strdup(s_orig)))
+    return NULL;
   for (p = s; p; p = strchr(p, ',')) {
     if (old != NULL) {
-      new = (HE *) xmalloc(sizeof(HE));
+      new = ALLOC(HE);
       old->next = new;
       old = new;
     } else {
-      old = (HE *) xmalloc(sizeof(HE));
+      old = ALLOC(HE);
       old->next = NULL;
     }
     c = strchr(p, ':');
-    if (c) {			/* Host and port */
+    if (c) {            /* Host and port */
       *c++ = '\0';
       old->host = strdup(p);
       old->port = atoi(c);
@@ -152,6 +153,7 @@ string2he(char *s)
       old->host = strdup(p);
 
   }
+  XFREE(s);
   return (old);
 }
 
@@ -182,7 +184,12 @@ amu_ldap_init(mnt_map *m, char *map, time_t *ts)
   ALD *aldh;
   CR *creds;
 
-  if (!STREQ(gopt.map_type, AMD_LDAP_TYPE)) {
+  /*
+   * XXX: by checking that map_type must be defined, aren't we
+   * excluding the possibility of automatic searches through all
+   * map types?
+   */
+  if (!gopt.map_type || !STREQ(gopt.map_type, AMD_LDAP_TYPE)) {
     return (ENOENT);
   }
 #ifdef DEBUG
@@ -191,8 +198,8 @@ amu_ldap_init(mnt_map *m, char *map, time_t *ts)
   }
 #endif /* DEBUG */
 
-  aldh = (ALD *) xmalloc(sizeof(ALD));
-  creds = (CR *) xmalloc(sizeof(CR));
+  aldh = ALLOC(ALD);
+  creds = ALLOC(CR);
 
   aldh->hostent = string2he(gopt.ldap_hostports);
   if (aldh->hostent == NULL) {
@@ -219,7 +226,7 @@ amu_ldap_init(mnt_map *m, char *map, time_t *ts)
   if (get_ldap_timestamp(aldh->ldap, map, ts))
     return (ENOENT);
 #ifdef DEBUG
-  dlog("Got timestamp for map %s: %d\n", map, *ts);
+  dlog("Got timestamp for map %s: %ld\n", map, *ts);
 #endif /* DEBUG */
 
   return (0);
@@ -233,6 +240,7 @@ amu_ldap_rebind(ALD *a)
   HE *h;
   CR *c = a->credentials;
   time_t now = clocktime();
+  int try;
 
   if (a->ldap != NULL) {
     if ((a->timestamp - now) > AMD_LDAP_TTL) {
@@ -245,7 +253,7 @@ amu_ldap_rebind(ALD *a)
       return (0);
   }
 
-  while (TRUE) {
+  for (try=0; try<10; try++) {	/* XXX: try up to 10 times (makes sense?) */
     for (h = a->hostent; h != NULL; h = h->next) {
       if ((ld = ldap_open(h->host, h->port)) == NULL) {
 	plog(XLOG_WARNING, "Unable to ldap_open to %s:%d\n", h->host, h->port);
@@ -272,12 +280,12 @@ amu_ldap_rebind(ALD *a)
 
 
 static int
-get_ldap_timestamp(LDAP * ld, char *map, time_t *ts)
+get_ldap_timestamp(LDAP *ld, char *map, time_t *ts)
 {
   struct timeval tv;
   char **vals, *end;
   char filter[MAXPATHLEN];
-  int i, err, nentries = 0;
+  int i, err = 0, nentries = 0;
   LDAPMessage *res, *entry;
 
   tv.tv_sec = 3;
@@ -299,13 +307,15 @@ get_ldap_timestamp(LDAP * ld, char *map, time_t *ts)
 			 &res);
     if (err == LDAP_SUCCESS)
       break;
+#ifdef DEBUG
     dlog("Timestamp search timed out, trying again...\n");
+#endif /* DEBUG */
   }
 
   if (err != LDAP_SUCCESS) {
     *ts = 0;
     plog(XLOG_USER, "LDAP timestamp search failed: %s\n",
-	 ldap_err2string(ld->ld_errno));
+	 ldap_err2string(err));
     return (ENOENT);
   }
 
@@ -339,7 +349,7 @@ get_ldap_timestamp(LDAP * ld, char *map, time_t *ts)
       err = ENOENT;
     }
     if (!*ts > 0) {
-      plog(XLOG_USER, "Nonpositive timestamp %d for map %s\n",
+      plog(XLOG_USER, "Nonpositive timestamp %ld for map %s\n",
 	   *ts, map);
       err = ENOENT;
     }
@@ -353,7 +363,7 @@ get_ldap_timestamp(LDAP * ld, char *map, time_t *ts)
   ldap_msgfree(res);
   ldap_msgfree(entry);
 #ifdef DEBUG
-  dlog("The timestamp for %s is %d (err=%d)\n", map, *ts, err);
+  dlog("The timestamp for %s is %ld (err=%d)\n", map, *ts, err);
 #endif /* DEBUG */
   return (err);
 }
@@ -364,7 +374,7 @@ amu_ldap_search(mnt_map *m, char *map, char *key, char **pval, time_t *ts)
 {
   char **vals, filter[MAXPATHLEN];
   struct timeval tv;
-  int i, err, nvals = 0, nentries = 0;
+  int i, err = 0, nvals = 0, nentries = 0;
   LDAPMessage *entry, *res;
   ALD *a = (ALD *) (m->map_data);
 
@@ -405,7 +415,7 @@ amu_ldap_search(mnt_map *m, char *map, char *key, char **pval, time_t *ts)
     return (ENOENT);
   default:
     plog(XLOG_USER, "LDAP search failed: %s\n",
-	 ldap_err2string(a->ldap->ld_errno));
+	 ldap_err2string(err));
     ldap_msgfree(res);
     return (EIO);
   }
@@ -452,7 +462,9 @@ amu_ldap_mtime(mnt_map *m, char *map, time_t *ts)
   ALD *aldh = (ALD *) (m->map_data);
 
   if (aldh == NULL) {
+#ifdef DEBUG
     dlog("LDAP panic: unable to find map data\n");
+#endif /* DEBUG */
     return (ENOENT);
   }
   if (amu_ldap_rebind(aldh)) {
