@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: info_nis.c,v 1.6.2.1 2001/01/10 03:23:06 ezk Exp $
+ * $Id: info_nis.c,v 1.6.2.2 2001/04/14 21:08:21 ezk Exp $
  *
  */
 
@@ -321,7 +321,7 @@ nis_search(mnt_map *m, char *map, char *key, char **val, time_t *tp)
     return ENOENT;
 
   default:
-    plog(XLOG_ERROR, "%s: %s", map, yperr_string(res));
+    plog(XLOG_ERROR, "nis_search: %s: %s", map, yperr_string(res));
     return EIO;
   }
 }
