@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mapc.c,v 1.7.2.2 2001/01/10 03:23:07 ezk Exp $
+ * $Id: mapc.c,v 1.7.2.3 2001/04/14 21:08:22 ezk Exp $
  *
  */
 
@@ -584,7 +584,7 @@ mapc_create(char *map, char *opt, const char *type)
 	 mt < maptypes + sizeof(maptypes) / sizeof(maptypes[0]);
 	 mt++) {
       if (STREQ(type, mt->name)) {
-	plog(XLOG_INFO, "initializing amd conf map %s of type %s", map, type);
+	plog(XLOG_INFO, "initializing amd.conf map %s of type %s", map, type);
 	if ((*mt->init) (m, map, &modify) == 0) {
 	  break;
 	} else {
