@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: sched.c,v 1.1.1.1 1998/11/05 02:04:49 ezk Exp $
+ * $Id: sched.c,v 1.4.2.2 2001/01/10 03:23:12 ezk Exp $
  *
  */
 
@@ -163,7 +163,7 @@ sched_task(cb_fun cf, voidp ca, voidp wchan)
   pjob *p = sched_job(cf, ca);
 
 #ifdef DEBUG
-  dlog("SLEEP on %#x", wchan);
+  dlog("SLEEP on %#lx", (unsigned long) wchan);
 #endif /* DEBUG */
   p->wchan = wchan;
   p->pid = 0;
@@ -219,7 +219,7 @@ do_task_notify(void)
   /*
    * Keep taking the first item off the list and processing it.
    *
-   * Done this way because the the callback can, quite reasonably,
+   * Done this way because the callback can, quite reasonably,
    * queue a new task, so no local reference into the list can be
    * held here.
    */
