@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: srvr_amfs_auto.c,v 1.3.2.2 2001/01/12 23:28:58 ro Exp $
+ * $Id: srvr_amfs_auto.c,v 1.3.2.3 2001/04/14 21:08:23 ezk Exp $
  *
  */
 
@@ -211,5 +211,5 @@ dup_srvr(fserver *fs)
 void
 srvrlog(fserver *fs, char *state)
 {
-  plog(XLOG_INFO, "file server %s type %s %s", fs->fs_host, fs->fs_type, state);
+  plog(XLOG_INFO, "file server %s, type %s, state %s", fs->fs_host, fs->fs_type, state);
 }
