@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: srvr_nfs.c,v 1.7.2.3 2001/01/12 23:28:58 ro Exp $
+ * $Id: srvr_nfs.c,v 1.7.2.5 2001/04/14 21:08:23 ezk Exp $
  *
  */
 
@@ -650,15 +650,11 @@ find_nfs_srvr(mntfs *mf)
 
 #ifdef MNTTAB_OPT_PROTO
   {
-    char *proto_opt = hasmntopt(&mnt, MNTTAB_OPT_PROTO);
+    char *proto_opt = hasmnteq(&mnt, MNTTAB_OPT_PROTO);
     if (proto_opt) {
       char **p;
-
-      proto_opt += sizeof(MNTTAB_OPT_PROTO) - 1; /* skip the "proto" */
-
       for (p = protocols; *p; p ++)
-	if (proto_opt[0] == '=' &&
-	    NSTREQ(&proto_opt[1], *p, strlen(*p))) {
+	if (NSTREQ(proto_opt, *p, strlen(*p))) {
 	  nfs_proto = *p;
 	  break;
 	}
@@ -674,7 +670,7 @@ find_nfs_srvr(mntfs *mf)
   if (hasmntopt(&mnt, "nfsv2")) {
     nfs_version = (u_long) 2;	/* nullify any ``vers=X'' statements */
     nfs_proto = "udp";		/* nullify any ``proto=tcp'' statements */
-    plog(XLOG_WARNING, "found compatiblity option \"nfsv2\": set options vers=2, proto=udp for host %s", host);
+    plog(XLOG_WARNING, "found compatiblity option \"nfsv2\": set options vers=2,proto=udp for host %s", host);
   }
 #endif /* HAVE_NFS_NFSV2_H */
 
@@ -686,7 +682,7 @@ find_nfs_srvr(mntfs *mf)
   }
   if (gopt.nfs_proto) {
     nfs_proto = gopt.nfs_proto;
-    plog(XLOG_INFO, "find_nfs_srvr: force NFS protocol to %s", nfs_proto);
+    plog(XLOG_INFO, "find_nfs_srvr: force NFS protocol transport to %s", nfs_proto);
   }
 
   /*
