@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mount_irix6.c,v 1.1.1.1 1998/11/05 02:04:36 ezk Exp $
+ * $Id: mount_irix6.c,v 1.4.2.1 2001/01/10 03:23:17 ezk Exp $
  *
  */
 
@@ -62,7 +62,7 @@ mount_irix(char *fsname, char *dir, int flags, MTYPE_TYPE type, voidp data)
 {
 
 #ifdef DEBUG
-  dlog("mount_irix: fsname %s, dir %s, type %d", fsname, dir, type);
+  dlog("mount_irix: fsname %s, dir %s, type %s", fsname, dir, type);
 #endif /* DEBUG */
 
 #ifdef HAVE_FS_NFS3
