@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mtab_aix.c,v 1.2 1998/12/27 06:25:00 ezk Exp $
+ * $Id: mtab_aix.c,v 1.5.2.1 2001/01/10 03:23:18 ezk Exp $
  *
  */
 
@@ -70,18 +70,27 @@ mnt_dup(struct vmount *mp)
 
   switch (mp->vmt_gfstype) {
 
-  case MNT_JFS:
+  case MOUNT_TYPE_UFS:
     ty = MNTTAB_TYPE_UFS;
     new_mp->mnt_fsname = strdup(fsname);
     break;
 
-  case MNT_NFS:
+  case MOUNT_TYPE_NFS:
     ty = MNTTAB_TYPE_NFS;
     new_mp->mnt_fsname = str3cat((char *) 0,
 				 vmt2dataptr(mp, VMT_HOSTNAME), ":",
 				 fsname);
     break;
 
+#ifdef HAVE_FS_NFS3
+  case MOUNT_TYPE_NFS3:
+    ty = MNTTAB_TYPE_NFS3;
+    new_mp->mnt_fsname = str3cat((char *) 0,
+				 vmt2dataptr(mp, VMT_HOSTNAME), ":",
+				 fsname);
+    break;
+#endif /* HAVE_FS_NFS3 */
+
   default:
     ty = "unknown";
     new_mp->mnt_fsname = strdup(fsname);
