@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_aix4.h,v 1.2 1998/12/27 06:25:02 ezk Exp $
+ * $Id: nfs_prot_aix4.h,v 1.4.2.2 2001/01/10 03:23:20 ezk Exp $
  *
  */
 
@@ -206,7 +206,7 @@ typedef writeargs	nfswriteargs;
 /*
  * EXTERNALS:
  */
-extern bool_t xdr_groups(XDR *xdrs, groups objp);
+extern bool_t xdr_groups(XDR *xdrs, groups *objp);
 
 /*
  * STRUCTURES:
