@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_aix4_2.h,v 1.2 1998/12/27 06:25:02 ezk Exp $
+ * $Id: nfs_prot_aix4_3.h,v 1.3.2.2 2001/01/10 03:23:21 ezk Exp $
  *
  */
 
@@ -47,7 +47,7 @@
 
 
 /*
- * AIX 4.2 and newer support NFS V.3, hence the separate header.
+ * AIX 4.3 and newer support NFS V.3, hence the separate header.
  */
 
 #ifdef HAVE_RPCSVC_NFS_PROT_H
@@ -219,7 +219,7 @@ typedef writeargs	nfswriteargs;
  */
 
 /*
- * AIX 4.2 has NFS V3, but it is undefined in the header files.
+ * AIX 4.3 has NFS V3, but it is undefined in the header files.
  * so I define everything that's needed for NFS V3 here.
  */
 #ifdef MNT_NFS3
@@ -305,9 +305,23 @@ typedef struct nfs_fh3 nfs_fh3;
 
 #endif /* MNT_NFS3 */
 
+/*
+ **************************************************************************
+ * AIX 4.3's autofs is not ported or tested yet...
+ * For now, undefine it or define dummy entries.
+ **************************************************************************
+ */
+#ifdef MNT_AUTOFS
+# undef MNT_AUTOFS
+#endif /* MNT_AUTOFS */
+#ifdef HAVE_FS_AUTOFS
+# undef HAVE_FS_AUTOFS
+#endif /* HAVE_FS_AUTOFS */
+
 /*
  * EXTERNALS:
  */
-extern bool_t xdr_groups(XDR *xdrs, groups objp);
+extern bool_t xdr_groups(XDR *xdrs, groups *objp);
+extern char *yperr_string (int incode);
 
 #endif /* not _AMU_NFS_PROT_H */
