@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_hpux11.h,v 1.1.1.1 1998/11/05 02:04:39 ezk Exp $
+ * $Id: nfs_prot_hpux11.h,v 1.4.2.3 2001/01/12 23:28:59 ro Exp $
  *
  */
 
@@ -92,6 +92,7 @@
 #define NFS_COOKIESIZE 4
 #define	MNTPATHLEN 1024
 #define	MNTNAMLEN 255
+#define HOSTNAMESZ 32      /* Max size of hostname in struct nfs_args */
 
 #define NFSMODE_FMT 0170000
 #define NFSMODE_DIR 0040000
@@ -151,14 +152,14 @@
 #define	NFSMNT_KERBEROS		0x20000	/* use kerberos credentials */
 #define	NFSMNT_POSIX		0x40000 /* static pathconf kludge info */
 #define	NFSMNT_LLOCK		0x80000	/* Local locking (no lock manager) */
-#define NFSMNT_FSNAME           0x1000000 /* set f/s name */
+#define NFSMNT_REMOUNT          0x100000 /* Remount from r/o to r/w */
+
+#define NFSMNT_FSNAME           0x1000000 /* FS name e.g. "host:/path/" */
+#define NFSMNT_NODEVS           0x2000000 /* no devices access (default on) */
+#define NFSMNT_IGNORE           0x4000000 /* ignore in mnttab */
 
 #define MS_FSS        0x00            /* fake flag to do nothing */
 
-/* no am-utils support for NFS V.3 yet */
-#undef MNTTYPE_NFS3
-#undef HAVE_FS_NFS3
-
 /*
  * ENUMS:
  */
@@ -245,24 +246,24 @@ typedef struct writeargs nfswriteargs;
  * EXTERNALS:
  */
 
-extern void * nfsproc_null_2_svc(void *, struct svc_req *);
-extern nfsattrstat * nfsproc_getattr_2_svc(nfs_fh *, struct svc_req *);
-extern nfsattrstat * nfsproc_setattr_2_svc(nfssattrargs *, struct svc_req *);
-extern void * nfsproc_root_2_svc(void *, struct svc_req *);
-extern nfsdiropres * nfsproc_lookup_2_svc(nfsdiropargs *, struct svc_req *);
-extern nfsreadlinkres * nfsproc_readlink_2_svc(nfs_fh *, struct svc_req *);
-extern nfsreadres * nfsproc_read_2_svc(nfsreadargs *, struct svc_req *);
-extern void * nfsproc_writecache_2_svc(void *, struct svc_req *);
-extern nfsattrstat * nfsproc_write_2_svc(nfswriteargs *, struct svc_req *);
-extern nfsdiropres * nfsproc_create_2_svc(nfscreateargs *, struct svc_req *);
-extern nfsstat * nfsproc_remove_2_svc(nfsdiropargs *, struct svc_req *);
-extern nfsstat * nfsproc_rename_2_svc(nfsrenameargs *, struct svc_req *);
-extern nfsstat * nfsproc_link_2_svc(nfslinkargs *, struct svc_req *);
-extern nfsstat * nfsproc_symlink_2_svc(nfssymlinkargs *, struct svc_req *);
-extern nfsdiropres * nfsproc_mkdir_2_svc(nfscreateargs *, struct svc_req *);
-extern nfsstat * nfsproc_rmdir_2_svc(nfsdiropargs *, struct svc_req *);
-extern nfsreaddirres * nfsproc_readdir_2_svc(nfsreaddirargs *, struct svc_req *);
-extern nfsstatfsres * nfsproc_statfs_2_svc(nfs_fh *, struct svc_req *);
+extern void *nfsproc_null_2_svc(void *, struct svc_req *);
+extern nfsattrstat *nfsproc_getattr_2_svc(nfs_fh *, struct svc_req *);
+extern nfsattrstat *nfsproc_setattr_2_svc(nfssattrargs *, struct svc_req *);
+extern void *nfsproc_root_2_svc(void *, struct svc_req *);
+extern nfsdiropres *nfsproc_lookup_2_svc(nfsdiropargs *, struct svc_req *);
+extern nfsreadlinkres *nfsproc_readlink_2_svc(nfs_fh *, struct svc_req *);
+extern nfsreadres *nfsproc_read_2_svc(nfsreadargs *, struct svc_req *);
+extern void *nfsproc_writecache_2_svc(void *, struct svc_req *);
+extern nfsattrstat *nfsproc_write_2_svc(nfswriteargs *, struct svc_req *);
+extern nfsdiropres *nfsproc_create_2_svc(nfscreateargs *, struct svc_req *);
+extern nfsstat *nfsproc_remove_2_svc(nfsdiropargs *, struct svc_req *);
+extern nfsstat *nfsproc_rename_2_svc(nfsrenameargs *, struct svc_req *);
+extern nfsstat *nfsproc_link_2_svc(nfslinkargs *, struct svc_req *);
+extern nfsstat *nfsproc_symlink_2_svc(nfssymlinkargs *, struct svc_req *);
+extern nfsdiropres *nfsproc_mkdir_2_svc(nfscreateargs *, struct svc_req *);
+extern nfsstat *nfsproc_rmdir_2_svc(nfsdiropargs *, struct svc_req *);
+extern nfsreaddirres *nfsproc_readdir_2_svc(nfsreaddirargs *, struct svc_req *);
+extern nfsstatfsres *nfsproc_statfs_2_svc(nfs_fh *, struct svc_req *);
 
 extern bool_t xdr_nfsstat(XDR *, nfsstat*);
 extern bool_t xdr_ftype(XDR *, nfsftype*);
@@ -298,7 +299,7 @@ extern bool_t xdr_statfsres(XDR *, nfsstatfsres*);
  * STRUCTURES:
  */
 
-/* HP shamelessly stole this from Solaris 2.5.1 */
+/* This is similar to Solaris 2.5.1 */
 struct nfs_args {
   struct netbuf		*addr;		/* file server address */
   struct netbuf		*syncaddr;	/* secure NFS time sync addr */
