@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_linux.h,v 1.5.2.3 2001/02/02 18:28:27 ezk Exp $
+ * $Id: nfs_prot_linux.h,v 1.5.2.5 2001/03/15 08:32:44 ib42 Exp $
  *
  */
 
@@ -55,6 +55,17 @@
  * file system for which the module isn't named as the file system mount
  * name.
  */
+#include <linux/version.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
+# ifndef MS_BIND
+#  define MS_BIND 4096
+# endif /* not MS_BIND */
+
+# ifndef MNTTYPE_LOFS
+#  define MNTTYPE_LOFS "bind"
+# endif /* not MNTTYPE_LOFS */
+#endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0) */
+
 #ifndef MNTTYPE_ISO9660
 # define MNTTYPE_ISO9660 "iso9660"
 #endif /* MNTTYPE_ISO9660 */
@@ -231,12 +242,8 @@ struct auto_args {
 };
 
 /*
- * This is truly screwed up, yet there is no other even *somewhat* easy way to do it...
- * struct nfs_mount_data uses struct nfs_fh, which we get from rpcsvc/nfs_prot.h,
- * and which is *different* from the struct nfs_fh in linux/nfs.h! Yet we need
- * rpcsvc/nfs_prot.h for its many definitions et al. So, in order not to end up
- * with a structure that is different from what the kernel expects, we define our
- * own here...
+ * We use our own definitions here, because the definitions in the
+ * kernel change the API (though not the ABI) *way* too often.
  */
 #undef nfs_args_t
 struct nfs2_fh {
@@ -249,23 +256,23 @@ struct nfs3_fh {
 };
 
 struct nfs_args {
-  int             version;                /* 1 */
-  int             fd;                     /* 1 */
-  struct nfs2_fh  old_root;               /* 1 */
-  int             flags;                  /* 1 */
-  int             rsize;                  /* 1 */
-  int             wsize;                  /* 1 */
-  int             timeo;                  /* 1 */
-  int             retrans;                /* 1 */
-  int             acregmin;               /* 1 */
-  int             acregmax;               /* 1 */
-  int             acdirmin;               /* 1 */
-  int             acdirmax;               /* 1 */
-  struct sockaddr_in addr;                /* 1 */
-  char            hostname[256];          /* 1 */
-  int             namlen;                 /* 2 */
-  unsigned int    bsize;                  /* 3 */
-  struct nfs3_fh  root;                   /* 4 */
+  int			version;	/* 1 */
+  int			fd;		/* 1 */
+  struct nfs2_fh	old_root;	/* 1 */
+  int			flags;		/* 1 */
+  int			rsize;		/* 1 */
+  int			wsize;		/* 1 */
+  int			timeo;		/* 1 */
+  int			retrans;	/* 1 */
+  int			acregmin;	/* 1 */
+  int			acregmax;	/* 1 */
+  int			acdirmin;	/* 1 */
+  int			acdirmax;	/* 1 */
+  struct sockaddr_in	addr;		/* 1 */
+  char			hostname[256];	/* 1 */
+  int			namlen;		/* 2 */
+  unsigned int		bsize;		/* 3 */
+  struct nfs3_fh	root;		/* 4 */
 };
 typedef struct nfs_args nfs_args_t;
 
