@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_sunos5_7.h,v 1.1 1999/01/01 22:36:37 ezk Exp $
+ * $Id: nfs_prot_sunos5_8.h,v 1.2.2.1 2001/01/10 03:23:26 ezk Exp $
  *
  */
 
@@ -112,7 +112,6 @@ typedef char *filename;
 typedef char *nfspath;
 typedef char nfscookie[NFS_COOKIESIZE];
 typedef enum nfsftype nfsftype;
-typedef enum nfsstat nfsstat;
 typedef struct attrstat nfsattrstat;
 typedef struct createargs nfscreateargs;
 typedef struct dirlist nfsdirlist;
@@ -389,101 +388,18 @@ struct statfsres {
 
 /*
  **************************************************************************
- * Solaris 2.6/2.7 changed autofs a lot.  A re-port to am-utils is required.
+ * Solaris 2.6/7/8 changed autofs a lot.  A re-port to am-utils is required.
  * For now, undefine it or define dummy entries.
  **************************************************************************
  */
 #ifdef MNTTYPE_AUTOFS
 # undef MNTTYPE_AUTOFS
 #endif /* MNTTYPE_AUTOFS */
+#ifdef MNTTAB_TYPE_AUTOFS
+# undef MNTTAB_TYPE_AUTOFS
+#endif /* MNTTAB_TYPE_AUTOFS */
 #ifdef HAVE_FS_AUTOFS
 # undef HAVE_FS_AUTOFS
 #endif /* HAVE_FS_AUTOFS */
-#ifdef HAVE_AM_FS_AUTOFS
-# undef HAVE_AM_FS_AUTOFS
-#endif /* HAVE_AM_FS_AUTOFS */
-
-
-/*
- **************************************************************************
- * Add LDAP definitions which are missing from Solaris 2.7
- **************************************************************************
- */
-#ifdef HAVE_LBER_H
-# include <lber.h>
-#endif /* HAVE_LBER_H */
-#ifdef HAVE_LDAP_H
-# include <ldap.h>
-#endif /* HAVE_LDAP_H */
-
-#define LDAP_FILT_MAXSIZ	1024
-#ifndef LDAP_MAX_ATTR_LEN
-# define LDAP_MAX_ATTR_LEN	100
-#endif /* LDAP_MAX_ATTR_LEN */
-#define LDAP_CACHE_BUCKETS	31	/* cache hash table size */
-
-typedef struct ldapcache {
-	LDAPMessage	*lc_buckets[LDAP_CACHE_BUCKETS];/* hash table */
-	LDAPMessage	*lc_requests;			/* unfulfilled reqs */
-	long		lc_timeout;			/* request timeout */
-	long		lc_maxmem;			/* memory to use */
-	long		lc_memused;			/* memory in use */
-	int		lc_enabled;			/* enabled? */
-	unsigned long	lc_options;			/* options */
-}  LDAPCache;
-
-/*
- * structure representing an ldap connection
- */
-struct ldap {
-	Sockbuf		ld_sb;		/* socket descriptor & buffer */
-	char		*ld_host;
-	int		ld_version;
-	char		ld_lberoptions;
-	int		ld_deref;
-	int		ld_timelimit;
-	int		ld_sizelimit;
-	LDAPFiltDesc	*ld_filtd;	/* from getfilter for ufn searches */
-	char		*ld_ufnprefix;	/* for incomplete ufn's */
-	int		ld_errno;
-	char		*ld_error;
-	char		*ld_matched;
-	int		ld_msgid;
-	/* do not mess with these */
-#ifdef LDAP_REFERRALS
-	LDAPRequest	*ld_requests;	/* list of outstanding requests */
-#else /* LDAP_REFERRALS */
-	LDAPMessage	*ld_requests;	/* list of outstanding requests */
-#endif /* LDAP_REFERRALS */
-	LDAPMessage	*ld_responses;	/* list of outstanding responses */
-	int		*ld_abandoned;	/* array of abandoned requests */
-	char		ld_attrbuffer[LDAP_MAX_ATTR_LEN];
-	LDAPCache	*ld_cache;	/* non-null if cache is initialized */
-	char		*ld_cldapdn;	/* DN used in connectionless search */
-	/* it is OK to change these next four values directly */
-	int		ld_cldaptries;	/* connectionless search retry count */
-	int		ld_cldaptimeout;/* time between retries */
-	int		ld_refhoplimit;	/* limit on referral nesting */
-	unsigned long	ld_options;	/* boolean options */
-#ifdef LDAP_DNS
-# define LDAP_OPT_DNS		0x00000001	/* use DN & DNS */
-#endif /* LDAP_DNS */
-#ifdef LDAP_REFERRALS
-# define LDAP_OPT_REFERRALS	0x00000002	/* chase referrals */
-#endif /* LDAP_REFERRALS */
-	/* do not mess with the rest though */
-	char		*ld_defhost;	/* full name of default server */
-	int		ld_defport;	/* port of default server */
-	BERTranslateProc ld_lber_encode_translate_proc;
-	BERTranslateProc ld_lber_decode_translate_proc;
-#ifdef LDAP_REFERRALS
-	LDAPConn	*ld_defconn;	/* default connection */
-	LDAPConn	*ld_conns;	/* list of server connections */
-	void		*ld_selectinfo;	/* platform specifics for select */
-	int		(*ld_rebindproc)( struct ldap *ld, char **dnp,
-				char **passwdp, int *authmethodp, int freeit );
-				/* routine to get info needed for re-bind */
-#endif /* LDAP_REFERRALS */
-};
 
 #endif /* not _AMU_NFS_PROT_H */
