@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: fixmount.c,v 1.2 1998/12/27 06:25:20 ezk Exp $
+ * $Id: fixmount.c,v 1.5.2.1 2001/01/10 03:23:32 ezk Exp $
  *
  */
 
@@ -86,15 +86,6 @@ void fix_rmtab(CLIENT *, char *, mountlist, int, int);
 void print_dump(mountlist);
 void usage(void);
 
-/* dummy variables */
-#if 0
-char *progname;
-char hostname[MAXHOSTNAMELEN];
-pid_t mypid;
-serv_state amd_state;
-int foreground, orig_umask;
-int debug_flags;
-#endif
 
 void
 usage(void)
