@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: fsinfo.h,v 1.2 1998/12/27 06:25:21 ezk Exp $
+ * $Id: fsinfo.h,v 1.4.2.2 2001/01/10 03:23:34 ezk Exp $
  *
  */
 
@@ -83,15 +83,20 @@ extern void analyze_automounts(qelem *);
 extern void analyze_hosts(qelem *);
 extern void compute_automount_point(char *, host *, char *);
 extern void dict_add(dict *, char *, char *);
-extern void error(char *fmt, ...);
-extern void fatal(char *fmt, ...);
+extern void error(char *fmt, ...)
+	__attribute__((__format__(__printf__, 1, 2)));
+extern void fatal(char *fmt, ...)
+	__attribute__((__format__(__printf__, 1, 2)));
 extern void gen_hdr(FILE *ef, char *hn);
 extern void info_hdr(FILE *ef, char *info);
 extern void init_que(qelem *);
 extern void ins_que(qelem *, qelem *);
-extern void lerror(ioloc *l, char *fmt, ...);
-extern void log(char *fmt, ...);
-extern void lwarning(ioloc *l, char *fmt, ...);
+extern void lerror(ioloc *l, char *fmt, ...)
+	__attribute__((__format__(__printf__, 2, 3)));
+extern void log(char *fmt, ...)
+	__attribute__((__format__(__printf__, 1, 2)));
+extern void lwarning(ioloc *l, char *fmt, ...)
+	__attribute__((__format__(__printf__, 2, 3)));
 extern void rem_que(qelem *);
 extern void set_disk_fs(disk_fs *, int, char *);
 extern void set_fsmount(fsmount *, int, char *);
@@ -100,7 +105,8 @@ extern void show_area_being_processed(char *area, int n);
 extern void show_new(char *msg);
 extern void warning(void);
 
-extern int yyerror(char *fmt, ...);
+extern int yyerror(char *fmt, ...)
+	__attribute__((__format__(__printf__, 1, 2)));
 extern void domain_strip(char *otherdom, char *localdom);
 /*
  * some systems such as DU-4.x have a different GNU flex in /usr/bin
