@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2001 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: hlfsd.h,v 1.1.1.1 1998/11/05 02:04:55 ezk Exp $
+ * $Id: hlfsd.h,v 1.4.2.2 2001/01/12 22:47:21 ro Exp $
  *
  * HLFSD was written at Columbia University Computer Science Department, by
  * Erez Zadok <ezk@cs.columbia.edu> and Alexander Dupuy <dupuy@cs.columbia.edu>
@@ -52,7 +52,7 @@
  * MACROS AND CONSTANTS:
  */
 
-#define HLFSD_VERSION	"hlfsd 1.1 (March 4, 1997-1998)"
+#define HLFSD_VERSION	"hlfsd 1.1 (1993-2001)"
 #define PERS_SPOOLMODE	0755
 #define OPEN_SPOOLMODE	01777
 #define DOTSTRING	"."
@@ -70,21 +70,16 @@
  * which define uid_t to be unsigned short, so I used the lowest common
  * size which is unsigned short.
  */
-#ifdef EXPERIMENTAL_UID_SIZE
-#define UID_SHIFT	30
-# define ROOTID		((1 << UID_SHIFT) - 1)
-# define SLINKID	((1 << UID_SHIFT) - 2)
-# define INVALIDID	((1 << UID_SHIFT) - 3)
-#else /* not EXPERIMENTAL_UID_SIZE */
 /*
  * XXX: this will cause problems to systems with UIDs greater than
  * MAX_UNSIGNED_SHORT-3.
  */
-# define ROOTID		(((unsigned short) ~0) - 1)
-# define SLINKID	(((unsigned short) ~0) - 2)
+#define ROOTID		(((unsigned short) ~0) - 1)
+#define SLINKID		(((unsigned short) ~0) - 2)
+#ifndef INVALIDID
+/* this is also defined in include/am_utils.h */
 # define INVALIDID	(((unsigned short) ~0) - 3)
-#endif /* not EXPERIMENTAL_UID_SIZE */
-
+#endif /* not INVALIDID */
 
 #define DOTCOOKIE	1
 #define DOTDOTCOOKIE	2
